@@ -55,15 +55,17 @@ protected:
 		NEW		= 1,
 		PASTE		= 2
 	};
-	
+
+	void prepare_new_partition( Byte_Value sector_size );
+
 	void Set_Confirm_Button( CONFIRMBUTTON button_type ) ;
 	void Set_MinMax_Text( Sector min, Sector max ) ;
 
 	double MB_PER_PIXEL ;
 	Sector TOTAL_MB ;
 	Frame_Resizer_Base *frame_resizer_base;
-	Partition selected_partition ;
-	
+	Partition new_partition;
+
 	Sector START; //the first sector of the first relevant partition ( this is either current or current -1 )  needed in Get_Resized_Partition()
 	Sector total_length ; //total amount of sectors ( this can be up to 3 partitions...)
 
@@ -90,8 +92,7 @@ protected:
 	bool fixed_start, GRIP ;
 	double before_value ;
 	FS fs ;
-	short BUF ; //used in resize and copy ( safety reasons )
-	
+
 private:
 	void Check_Change( ) ;
 	
