@@ -28,6 +28,23 @@
 namespace GParted
 {
 
+enum ExecFlags
+{
+	EXEC_NONE         = 1 << 0,
+	EXEC_CHECK_STATUS = 1 << 1,  // Set the status of the command in the operation
+	                             // details based on the exit status being zero or
+	                             // non-zero.  Must either use this flag when calling
+	                             // ::execute_command() or call ::set_status()
+	                             // afterwards.
+	EXEC_CANCEL_SAFE  = 1 << 2
+};
+
+inline ExecFlags operator|( ExecFlags lhs, ExecFlags rhs )
+	{ return static_cast<ExecFlags>( static_cast<unsigned>(lhs) | static_cast<unsigned>(rhs) ); }
+
+inline ExecFlags operator&( ExecFlags lhs, ExecFlags rhs )
+	{ return static_cast<ExecFlags>( static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs) ); }
+
 class FileSystem
 {
 public:
@@ -57,12 +74,11 @@ public:
 			   OperationDetail & operationdetail ) { return false; };
 	virtual bool check_repair( const Partition & partition, OperationDetail & operationdetail ) { return false; };
 	virtual bool remove( const Partition & partition, OperationDetail & operationdetail ) { return true; };
-	bool success;
+
 protected:
 	int execute_command( const Glib::ustring & command, OperationDetail & operationdetail,
-			     bool checkstatus = false, bool cancel_safe = false );
-	int execute_command_timed( const Glib::ustring & command, OperationDetail & operationdetail ) {
-		return execute_command( command, operationdetail, true ); }
+	                     ExecFlags flags = EXEC_NONE );
+	void set_status( OperationDetail & operationdetail, bool success );
 	void execute_command_eof();
 	Glib::ustring mk_temp_dir( const Glib::ustring & infix, OperationDetail & operationdetail ) ;
 	void rm_temp_dir( const Glib::ustring dir_name, OperationDetail & operationdetail ) ;
