@@ -27,7 +27,7 @@ namespace GParted
 class ntfs : public FileSystem
 {
 public:
-	const Glib::ustring get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) ;
+	const Glib::ustring get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) const;
 	FS get_filesystem_support() ;
 	void set_used_sectors( Partition & partition ) ;
 	void read_label( Partition & partition ) ;
