@@ -21,7 +21,11 @@
 namespace GParted
 {
 
-Dialog_Partition_New::Dialog_Partition_New()
+Dialog_Partition_New::Dialog_Partition_New( const Device & device,
+                                            const Partition & partition,
+                                            bool any_extended,
+                                            unsigned short new_count,
+                                            const std::vector<FS> & FILESYSTEMS )
 {
 	/*TO TRANSLATORS: dialogtitle */
 	this ->set_title( _("Create new Partition") ) ;
@@ -30,17 +34,18 @@ Dialog_Partition_New::Dialog_Partition_New()
 	
 	//set used (in pixels)...
 	frame_resizer_base ->set_used( 0 ) ;
+
+	set_data(device, partition, any_extended, new_count, FILESYSTEMS );
 }
 
-void Dialog_Partition_New::Set_Data( const Partition & partition,
-				     bool any_extended,
-				     unsigned short new_count, 
-				     const std::vector<FS> & FILESYSTEMS,
-				     bool only_unformatted,
-				     Glib::ustring disktype )
+void Dialog_Partition_New::set_data( const Device & device,
+                                     const Partition & partition,
+                                     bool any_extended,
+                                     unsigned short new_count,
+                                     const std::vector<FS> & FILESYSTEMS )
 {
 	this ->new_count = new_count;
-	this ->selected_partition = partition;
+	new_partition = partition;
 
 	// Copy only supported file systems from GParted_Core FILESYSTEMS vector.  Add
 	// FS_CLEARED, FS_UNFORMATTED and FS_EXTENDED at the end.  This decides the order
@@ -86,7 +91,7 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 	menu_type .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("Extended Partition") ) ) ;
 	
 	//determine which PartitionType is allowed
-	if ( disktype != "msdos" && disktype != "dvh" )
+	if ( device.disktype != "msdos" && device.disktype != "dvh" )
 	{
 		menu_type .items()[ 1 ] .set_sensitive( false ); 
 		menu_type .items()[ 2 ] .set_sensitive( false );
@@ -115,34 +120,40 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 		sigc::bind<bool>( sigc::mem_fun( *this, &Dialog_Partition_New::optionmenu_changed ), true ) );
 	table_create .attach( optionmenu_type, 1, 2, 0, 1, Gtk::FILL );
 	
+	// Partition name
+	table_create.attach( *Utils::mk_label( static_cast<Glib::ustring>( _("Partition name:") ) + "\t" ),
+	                     0, 1, 1, 2, Gtk::FILL );
+	// Initialise text entry box
+	partition_name_entry.set_width_chars( 20 );
+	partition_name_entry.set_sensitive( device.partition_naming_supported() );
+	partition_name_entry.set_max_length( device.get_max_partition_name_length() );
+	// Add entry box to table
+	table_create .attach( partition_name_entry, 1, 2, 1, 2, Gtk::FILL );
+
 	//file systems to choose from 
 	table_create .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("File system:") ) + "\t" ),
-			     0, 1, 1, 2,
-			     Gtk::FILL );
-	
-	Build_Filesystems_Menu( only_unformatted ) ;
+	                      0, 1, 2, 3, Gtk::FILL );
+
+	Build_Filesystems_Menu( device.readonly );
 	 
 	optionmenu_filesystem .set_menu( menu_filesystem );
 	optionmenu_filesystem .signal_changed() .connect( 
 		sigc::bind<bool>( sigc::mem_fun( *this, &Dialog_Partition_New::optionmenu_changed ), false ) );
-	table_create .attach( optionmenu_filesystem, 1, 2, 1, 2, Gtk::FILL );
+	table_create .attach( optionmenu_filesystem, 1, 2, 2, 3, Gtk::FILL );
 
 	//Label
 	table_create .attach( * Utils::mk_label( Glib::ustring( _("Label:") ) ),
-			0, 1, 3, 4,	Gtk::FILL ) ;
+	                      0, 1, 3, 4, Gtk::FILL );
 	//Create Text entry box
-	entry .set_width_chars( 20 );
-	entry .set_activates_default( true );
-	entry .set_text( partition.get_filesystem_label() );
-	entry .select_region( 0, entry .get_text_length() );
+	filesystem_label_entry.set_width_chars( 20 );
 	//Add entry box to table
-	table_create .attach( entry, 1, 2, 3, 4, Gtk::FILL ) ;
+	table_create.attach( filesystem_label_entry, 1, 2, 3, 4, Gtk::FILL );
 
 	//set some widely used values...
-	MIN_SPACE_BEFORE_MB = Dialog_Base_Partition::MB_Needed_for_Boot_Record( selected_partition ) ;
+	MIN_SPACE_BEFORE_MB = Dialog_Base_Partition::MB_Needed_for_Boot_Record( new_partition );
 	START = partition.sector_start ;
 	total_length = partition.sector_end - partition.sector_start ;
-	TOTAL_MB = Utils::round( Utils::sector_to_unit( this ->selected_partition .get_sector_length(), this ->selected_partition .sector_size, UNIT_MIB ) ) ;
+	TOTAL_MB = Utils::round( Utils::sector_to_unit( new_partition.get_sector_length(), new_partition.sector_size, UNIT_MIB ) );
 	MB_PER_PIXEL = TOTAL_MB / 500.00 ;
 	
 	//set first enabled file system
@@ -187,28 +198,31 @@ Partition Dialog_Partition_New::Get_New_Partition( Byte_Value sector_size )
 	
 	/* due to loss of precision during calcs from Sector -> MiB and back, it is possible the new 
 	 * partition thinks it's bigger then it can be. Here we try to solve this.*/
-	if ( new_start < selected_partition.sector_start )
-		new_start = selected_partition.sector_start ;
-	if  ( new_end > selected_partition.sector_end )
-		new_end = selected_partition.sector_end ;
-	
+	if ( new_start < new_partition.sector_start )
+		new_start = new_partition.sector_start;
+	if  ( new_end > new_partition.sector_end )
+		new_end = new_partition.sector_end;
+
 	part_temp .status = GParted::STAT_NEW ;
-	part_temp.Set( selected_partition.device_path,
+	part_temp.Set( new_partition.device_path,
 	               String::ucompose( _("New Partition #%1"), new_count ),
-	               new_count, part_type, selected_partition.whole_device,
+	               new_count, part_type, new_partition.whole_device,
 	               FILESYSTEMS[optionmenu_filesystem.get_history()].filesystem,
 	               new_start, new_end,
 	               sector_size,
-	               selected_partition.inside_extended, false );
+	               new_partition.inside_extended, false );
+
+	// Retrieve partition name
+	part_temp.name = Utils::trim( partition_name_entry.get_text() );
 
 	//Retrieve Label info
-	part_temp.set_filesystem_label( Utils::trim( entry.get_text() ) );
+	part_temp.set_filesystem_label( Utils::trim( filesystem_label_entry.get_text() ) );
 	
 	//grow new partition a bit if freespaces are < 1 MiB
-	if ( (part_temp.sector_start - selected_partition.sector_start) < (MEBIBYTE / sector_size) ) 
-		part_temp.sector_start = selected_partition.sector_start ;
-	if ( (selected_partition.sector_end - part_temp.sector_end) < (MEBIBYTE / sector_size) ) 
-		part_temp.sector_end = selected_partition.sector_end ;
+	if ( (part_temp.sector_start - new_partition.sector_start) < (MEBIBYTE / sector_size) )
+		part_temp.sector_start = new_partition.sector_start;
+	if ( (new_partition.sector_end - part_temp.sector_end) < (MEBIBYTE / sector_size) )
+		part_temp.sector_end = new_partition.sector_end;
 	
 	//if new is extended...
 	if ( part_temp .type == GParted::TYPE_EXTENDED )
@@ -278,8 +292,8 @@ void Dialog_Partition_New::optionmenu_changed( bool type )
 		if ( fs .MIN < MEBIBYTE )
 			fs .MIN = MEBIBYTE ;
 
-		if ( selected_partition .get_byte_length() < fs .MIN )
-			fs .MIN = selected_partition .get_byte_length() ;
+		if ( new_partition.get_byte_length() < fs.MIN )
+			fs .MIN = new_partition.get_byte_length();
 
 		if ( ! fs .MAX || ( fs .MAX > ((TOTAL_MB - MIN_SPACE_BEFORE_MB) * MEBIBYTE) ) )
 			fs .MAX = ((TOTAL_MB - MIN_SPACE_BEFORE_MB) * MEBIBYTE) ;
@@ -318,8 +332,8 @@ void Dialog_Partition_New::optionmenu_changed( bool type )
 		frame_resizer_base->set_rgb_partition_color(color_temp);
 	}
 
-	//set partition name entry box length
-	entry .set_max_length( Utils::get_filesystem_label_maxlength( fs.filesystem ) ) ;
+	// Maximum length of the file system label varies according to the selected file system type.
+	filesystem_label_entry.set_max_length( Utils::get_filesystem_label_maxlength( fs.filesystem ) );
 
 	frame_resizer_base ->Draw_Partition() ;
 }
@@ -337,7 +351,7 @@ void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted )
 			Gtk::Menu_Helpers::MenuElem( Utils::get_filesystem_string( FILESYSTEMS[ t ] .filesystem ) ) ) ;
 		menu_filesystem .items() .back() .set_sensitive(
 			! only_unformatted && FILESYSTEMS[ t ] .create &&
-			this ->selected_partition .get_byte_length() >= FILESYSTEMS[ t ] .MIN ) ;
+			new_partition.get_byte_length() >= FILESYSTEMS[t].MIN );
 		//use ext4/3/2 as first/second/third choice default file system
 		//(Depends on ordering in FILESYSTEMS for preference)
 		if ( ( FILESYSTEMS[ t ] .filesystem == FS_EXT2 ||
