@@ -54,7 +54,7 @@ const Glib::ustring FileSystem::get_generic_text( CUSTOM_TEXT ttype, int index )
 
 void FileSystem::store_exit_status( GPid pid, int status )
 {
-	exit_status = status;
+	exit_status = Utils::decode_wait_status( status );
 	running = false;
 	if (pipecount == 0) // pipes finished first
 		Gtk::Main::quit();
@@ -80,9 +80,9 @@ static void setup_child()
 }
 
 int FileSystem::execute_command( const Glib::ustring & command, OperationDetail & operationdetail,
-				 bool checkstatus, bool cancel_safe )
+                                 ExecFlags flags )
 {
-	operationdetail .add_child( OperationDetail( command, checkstatus ? STATUS_EXECUTE : STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
+	operationdetail.add_child( OperationDetail( command, STATUS_EXECUTE, FONT_BOLD_ITALIC ) );
 	Glib::Pid pid;
 	// set up pipes for capture
 	int out, err;
@@ -102,7 +102,7 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 		std::cerr << e.what() << std::endl;
 		operationdetail.get_last_child().add_child(
 			OperationDetail( e.what(), STATUS_ERROR, FONT_ITALIC ) );
-		return 1;
+		return Utils::get_failure_status( e );
 	}
 	fcntl( out, F_SETFL, O_NONBLOCK );
 	fcntl( err, F_SETFL, O_NONBLOCK );
@@ -132,10 +132,11 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 		sigc::bind(
 			sigc::ptr_fun( cancel_command ),
 			pid,
-			cancel_safe ));
+			flags & EXEC_CANCEL_SAFE ) );
 	Gtk::Main::run();
 
-	if (checkstatus) {
+	if ( flags & EXEC_CHECK_STATUS )
+	{
 		if ( !exit_status )
 			operationdetail.get_last_child().set_status( STATUS_SUCCES );
 		else
@@ -146,6 +147,11 @@ int FileSystem::execute_command( const Glib::ustring & command, OperationDetail
 	return exit_status;
 }
 
+void FileSystem::set_status( OperationDetail & operationdetail, bool success )
+{
+	operationdetail.get_last_child().set_status( success ? STATUS_SUCCES : STATUS_ERROR );
+}
+
 void FileSystem::execute_command_eof()
 {
 	if (--pipecount)
