@@ -192,7 +192,8 @@ void ext2::read_label( Partition & partition )
 bool ext2::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
 	return ! execute_command( label_cmd + " " + partition.get_path() +
-	                          " \"" + partition.get_filesystem_label() + "\"", operationdetail ) ;
+	                          " \"" + partition.get_filesystem_label() + "\"",
+	                          operationdetail, EXEC_CHECK_STATUS );
 }
 
 void ext2::read_uuid( Partition & partition )
@@ -213,14 +214,15 @@ void ext2::read_uuid( Partition & partition )
 
 bool ext2::write_uuid( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( tune_cmd + " -U random " + partition .get_path(), operationdetail ) ;
+	return ! execute_command( tune_cmd + " -U random " + partition .get_path(),
+	                          operationdetail, EXEC_CHECK_STATUS );
 }
 
 bool ext2::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	return ! execute_command( mkfs_cmd + " -F -L \"" + new_partition.get_filesystem_label() + "\" " +
 	                          new_partition.get_path(),
-	                          operationdetail, false, true );
+	                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
 }
 
 bool ext2::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
@@ -231,17 +233,16 @@ bool ext2::resize( const Partition & partition_new, OperationDetail & operationd
 		str_temp += " " + Utils::num_to_str( floor( Utils::sector_to_unit(
 					partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) ) + "K";
 
-	return ! execute_command( str_temp, operationdetail ) ;
+	return ! execute_command( str_temp, operationdetail, EXEC_CHECK_STATUS );
 }
 
 bool ext2::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
 	exit_status = execute_command( fsck_cmd + " -f -y -v -C 0 " + partition.get_path(), operationdetail,
-				       false, true );
-
-	//exitstatus 256 isn't documented, but it's returned when the 'FILE SYSTEM IS MODIFIED'
-	//this is quite normal (especially after a copy) so we let the function return true...
-	return ( exit_status == 0 || exit_status == 1 || exit_status == 2 || exit_status == 256 ) ;
+	                               EXEC_CANCEL_SAFE );
+	bool success = ( exit_status == 0 || exit_status == 1 || exit_status == 2 );
+	set_status( operationdetail, success );
+	return success;
 }
 
 bool ext2::move( const Partition & partition_new,
@@ -254,10 +255,10 @@ bool ext2::move( const Partition & partition_new,
 	offset = Utils::num_to_str( llabs(distance) * partition_new.sector_size );
 	if ( distance < 0 )
 		return ! execute_command( image_cmd + " -ra -p -o " + offset + " " + partition_new.get_path(),
-		                          operationdetail, true, true );
+		                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
 	else
 		return ! execute_command( image_cmd + " -ra -p -O " + offset + " " + partition_new.get_path(),
-		                          operationdetail, true, true );
+		                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
 
 }
 
@@ -266,7 +267,7 @@ bool ext2::copy( const Partition & src_part,
                  OperationDetail & operationdetail )
 {
 	return ! execute_command( image_cmd + " -ra -p " + src_part.get_path() + " " + dest_part.get_path(),
-	                          operationdetail, true, true );
+	                          operationdetail, EXEC_CHECK_STATUS|EXEC_CANCEL_SAFE );
 }
 
 } //GParted
